TextCache

Struct TextCache 

pub struct TextCache<'a, F: ThreadSafeFont> { /* private fields */ }
A cache for character textures (also holds the font)

Implementations

Source

impl<'a, F: ThreadSafeFont> TextCache<'a, F>

pub fn new(font: F) -> Self

Creates a new TextCache

pub fn switch_font(&mut self, new_font: F)

Switches this cache to a different font (and clears the cache so the characters can be re-rendered)

pub fn clear(&mut self)

Clears the cache, probably should only be done if the program is actually low on ram or vram